<?php

/**
 * Implements hook_permission().
 */
function ustudio_permission() {
  return array(
      'administer ustudio' => array(
          'title'       => t('administer uStudio'),
          'description' => t('Access the uStudio configuration options.'),
      ),
      'access ustudio'     => array(
          'title'       => t('use uStudio'),
          'description' => t('Access the uStudio video browsing form.'),
      )
  );
}

/**
 * Implements hook_menu().
 */
function ustudio_menu() {
  $items = array();

  $items['admin/config/services/ustudio'] = array(
      'title'            => 'uStudio',
      'description'      => 'Manage uStudio Settings.',
      'page callback'    => 'drupal_get_form',
      'page arguments'   => array('ustudio_admin_settings'),
      'access arguments' => array('administer ustudio'),
      'file'             => 'includes/ustudio.admin.php',
      'type'             => MENU_NORMAL_ITEM,
  );

  $items['ustudio/video/browse'] = array(
      'title'            => 'uStudio',
      'description'      => 'Browse remote videos from uStudio service',
      'page callback'    => 'drupal_get_form',
      'page arguments'   => array('ustudio_video_browse_form'),
      'access arguments' => array('access ustudio'),
      'file'             => 'includes/ustudio.pages.php',
      'type'             => MENU_CALLBACK,
  );

  $items['ustudio/api/%'] = array(
      'title'            => 'uStudio',
      'description'      => 'Browse remote videos from uStudio service',
      'page callback'    => 'ustudio_api_load',
      'page arguments'   => array(2),
      'access arguments' => array('access ustudio'),
      'file'             => 'includes/ustudio.pages.php',
      'type'             => MENU_CALLBACK,
  );

  return $items;
}

/**
 * Implements hook_theme().
 */
function ustudio_theme() {
  return array(
      'ustudio_videos' => array(
          'variables' => array('videos' => array()),
          'path'      => drupal_get_path('module', 'ustudio') . '/templates',
          'template'  => 'ustudio-videos'
      )
  );
}

/**
 * Implements hook_wysiwyg_plugin().
 */
function ustudio_wysiwyg_plugin($editor, $version) {
  if ('ckeditor' === $editor) {
    $module_path = drupal_get_path('module', 'ustudio');
    drupal_add_css($module_path . '/wysiwyg_plugins/ustudio_ckeditor/styles/plugin.css');

    return array(
        // This key (ustudio) needs to be the same as the plugin name used in
        // CKEDITOR.plugins.add() in plugin.js
        'ustudio' => array(
            // A URL to the plugin's homepage.
            'url'       => '',
            // The full path to the native editor plugin, no trailing slash.
            // Ignored when 'internal' is set to TRUE below.
            'path'      => $module_path . '/wysiwyg_plugins/ustudio_ckeditor',
            // The name of the plugin's main JavaScript file.
            // Ignored when 'internal' is set to TRUE below.
            // Default value depends on which editor the plugin is for.
            'filename'  => 'plugin.js',
            'css files' => array('styles/plugin.css'),
            // A list of buttons provided by this native plugin. The key has to
            // match the corresponding JavaScript implementation - when it's
            // created using editor.ui.addButton(). The value is is displayed on
            // the editor configuration form only.
            'buttons'   => array('uStudio' => t('uStudio browser')),
            // Boolean whether the editor needs to load this plugin. When TRUE,
            // the editor will automatically load the plugin based on the 'path'
            // variable provided. If FALSE, the plugin either does not need to
            // be loaded or is already loaded by something else on the page.
            // Most plugins should define TRUE here.
            'load'      => TRUE,
            // Boolean whether this plugin is a native plugin, i.e. shipped with
            // the editor. Definition must be ommitted for plugins provided by
            // other modules. TRUE means 'path' and 'filename' above are ignored
            // and the plugin is instead loaded from the editor's plugin folder.
            'internal'  => FALSE,
        ),
    );
  }
}

/**
 * Implements hook_ckeditor_plugin()
 */
function ustudio_ckeditor_plugin() {
  $module_path = drupal_get_path('module', 'ustudio');
  drupal_add_css($module_path . '/wysiwyg_plugins/ustudio_ckeditor/styles/plugin.css');
  return array(
      // This key (youtube) needs to be the same as the plugin name used in
      // CKEDITOR.plugins.add() in plugin.js
      'ustudio' => array(
          // Name of the plugin used to write it. Also needs to be the same as the
          // plugin name used in CKEDITOR.plugins.add() in plugin.js
          'name'    => 'ustudio',
          // Description of the plugin - it would be displayed in the plugins management section of profile settings.
          'desc'    => t('Embed a uStudion video into the content area using the video url'),
          // The full path to the CKEditor plugins directory, with the trailing slash.
          'path'    => drupal_get_path('module', 'ustudio') . '/wysiwyg_plugins/ustudio_ckeditor/',
          // A list of buttons provided by this plugin. The key has to
          // match the corresponding JavaScript implementation - when it's
          // created using editor.ui.addButton(). If you don't do this, your button
          // won't be available for drag 'n drop ordering on the plugins management
          // section of profile settings
          'buttons' => array(
              'uStudio' => array(
                  'icon'  => 'images/icon.png',
                  'label' => 'uStudio Embed',
              )
          )
      )
  );
}

/**
 * Implements hook_attach_plugin().
 */
function ustudio_attach_plugin() {
  return array(
      'ustudio' => array(
          'title'       => 'Attach uStudio videos, playlists',
          'description' => 'Use this syntax: [attach_ustudio_video|id=VIDEO_ID] or [attach_ustudio_playlist|id=PLAYLIST_ID]',
          'callback'    => 'ustudio_attach_ustudio_process',
          'options'     => array(),
          'suffixes'    => array('ustudio_video', 'ustudio_playlist'),
          'wrapper'     => '',
      ),
  );
}

/**
 * Attach integration callback
 */
function ustudio_attach_ustudio_process($params) {
  $allowed_suffix = array('ustudio_video', 'ustudio_playlist');

  if (in_array($params['suffix'], $allowed_suffix) && isset($params['id'])) {
    switch ($params['suffix']) {
      case 'ustudio_video':
        $ustudio = ustudio();
        $video = $ustudio->getVideo($params['id']);
        return '<iframe src="' . $video->preview_embed_url . '" width="640"
            height="360" scrolling="no" webkitallowfullscreen="true" mozallowfullscreen="true"
            allowfullscreen="true" frameborder="0"></iframe>';

      case 'ustudio_playlist':
        $ustudio = ustudio();
        $destination = $ustudio->getDestination($params['id']);
        return '<iframe src="' . $destination->player_embed_url . '" width="640"
            height="360" scrolling="no" webkitallowfullscreen="true" mozallowfullscreen="true"
            allowfullscreen="true" frameborder="0"></iframe>';
    }
  }
}
