<?php

use Drupal\ustudio\Ustudio;

/**
 * Implements hook_form().
 *
 * Provide remote video browsing from uStudio service.
 */
function ustudio_video_browse_form($form, &$form_state) {
  $ustudio = new Ustudio(variable_get('ustudio_uid'), variable_get('ustudio_token'));

  // get query params
  $query = drupal_get_query_parameters();

  // build "collection" select options
  $collections = $ustudio->getCollections();
  $collections_options = array(NULL => t('-- Select collections --'));

  foreach ($collections->collections as $collection) {
    $collectionId = $collection->uid;
    $collections_options[$collectionId] = $collection->name;
  }

  $form['search'] = array(
      '#type'  => 'fieldset',
      '#title' => t('Search')
  );

  $form['search']['keyword'] = array(
      '#type'          => 'textfield',
      '#title'         => t('Keyword'),
      '#default_value' => isset($query['keyword']) ? $query['keyword'] : ''
  );

  $form['search']['collection'] = array(
      '#type'    => 'select',
      '#title'   => t('Collection'),
      '#options' => $collections_options
  );

  $form['search']['search'] = array(
      '#type'  => 'submit',
      '#value' => t('Search'),
      '#ajax'  => array(
          'wrapper'  => 'ustudio-videos-wrapper',
          'callback' => 'ustudio_video_browse_form_ajax'
      )
  );

  if (!empty($form_state['values']['collection'])) {
    $videos_by_collection = $ustudio->getCollectionVideos($form_state['values']['collection'], array());
    $videos = $videos_by_collection;
  }
  else if (!empty($form_state['values']['keyword'])) {
    $videos = $ustudio->getVideos(array('query' => $form_state['values']['keyword']));
  }
  else {
    $videos = $ustudio->getVideos();
  }

  $form['videos'] = array(
      '#prefix' => '<div id="ustudio-videos-wrapper">',
      '#suffix' => '</div>',
      '#markup' => theme('ustudio_videos', array('videos' => $videos->videos))
  );

  $form['#attached']['css'][] = drupal_get_path('module', 'ustudio') . '/misc/ustudio.browser.css';

  return $form;
}

/**
 * Ajax callback for Search button
 */
function ustudio_video_browse_form_ajax($form, $form_state) {
  return $form['videos'];
}

/**
 * Mark form as rebuild
 */
function ustudio_video_browse_form_submit($form, &$form_state) {
  $form_state['rebuild'] = TRUE;
}

/**
 * uStudio API proxy callback - /ustudio/api/%
 */
function ustudio_api_load($type) {
  $allowed_types = array(
      'collections' => array(
          'method' => 'getCollections'
      ),
      'videos'      => array(
          'method'  => 'getVideos',
          'queries' => TRUE, // support get queries params
      ),
      'video'       => array(
          'method'    => 'getVideo',
          'arguments' => array(3)
      )
  );

  $ustudio = ustudio();

  if (in_array($type, array_keys($allowed_types)) && method_exists($ustudio, $allowed_types[$type]['method'])) {
    $method = $allowed_types[$type]['method'];
    if (!empty($allowed_types[$type]['arguments'])) {
      $method_arguments = array();
      foreach ($allowed_types[$type]['arguments'] as $argIndex) {
        if (arg($argIndex)) {
          $method_arguments[] = arg($argIndex);
        }
      }
      $result = call_user_func_array(array($ustudio, $method), $method_arguments);
    }
    else if (!empty($allowed_types[$type]['queries'])) {
      $queries = drupal_get_query_parameters();
      $result = call_user_func_array(array($ustudio, $method), array($queries));
    }
    else {
      $result = $ustudio->{$method}();
    }

    drupal_json_output($result);
    exit();
  }
}
