/**
 * @file Plugin for inserting Drupal embeded media
 */
(function ($) {
  var inputs = {};

  function getCollections(cb) {
    $.ajax({
      url: Drupal.settings.basePath + 'ustudio/api/collections',
      method: 'GET',
      success: function (data) {
        cb(null, data);
      },
      error: function (err) {
        cb(err);
      }
    });
  }

  function getVideos(filter, cb) {
    var self = this;
    console.log('getVideos', keyword, cb);
    if (typeof filter == 'function') {
      cb = filter;
      filter = null;
    }

    var url = Drupal.settings.basePath + 'ustudio/api/videos';
    if (filter && filter.keyword) {
      url += '?query=' + filter.keyword;
    }

    $.ajax({
      url: url,
      method: 'GET',
      success: function (data) {
        cb.apply(self, [null, data]);
      },
      error: function (err) {
        cb.apply(self, [err]);
      }
    });
  }

  function getVideoDetail(videoId, cb) {
    $.ajax({
      url: Drupal.settings.basePath + 'ustudio/api/video/' + videoId,
      method: 'GET',
      success: function (data) {
        cb(null, data);
      },
      error: function (err) {
        cb(err);
      }
    });
  }

  function renderVideos(err, data) {
    var html = [];
    var elem = this.getElement();

    if (err) {
      console.error(err);
      return;
    }

    $.each(data.videos, function () {
      html.push('' +
              '<div class="video-item" data-uid="' + this.uid + '">' +
              '<img src="' + this.image_url + '" style="width: 150px; height: auto;">' +
              '<p>' + this.title + '</p>' +
              '</div>'
              );
    });

    elem.setHtml(html.join('\n'));

    $('.video-item', elem.$).live('click', function () {
      $('.video-item', elem.$).removeClass('active');
      $(this).toggleClass('active');

      // extract videoId from attr
      var videoId = $(this).attr('data-uid');

      // save videoId
      elem.setValue(videoId);

      // click button Ok
      var ckDialog = window.CKEDITOR.dialog.getCurrent();
      var ckCancel = ckDialog._.buttons['cancel'];
      var ckOk = ckDialog._.buttons['ok'];

      ckOk.click();
    });
  }

  // All CKEditor plugins are created by using the CKEDITOR.plugins.add function
  // The plugin name here needs to be the same as in hook_ckeditor_plugin()
  // or hook_wysiwyg_plugin()
  CKEDITOR.plugins.add('ustudio', {
    // the init() function is called upon the initialization of the editor instance
    init: function (editor) {
      var pluginDirectory = this.path;

      console.info('ustudio plugin init');
      editor.addContentsCss(pluginDirectory + 'styles/plugin.css');

      // Register the dialog. The actual dialog definition is below.
      CKEDITOR.dialog.add('ustudioDialog', ytDialogDefinition);

      // Now that CKEditor knows about our dialog, we can create a
      // command that will open it
      editor.addCommand('ustudioDialogCmd', new CKEDITOR.dialogCommand('ustudioDialog'));

      // Finally we can assign the command to a new button that we'll call youtube
      // Don't forget, the button needs to be assigned to the toolbar. Note that
      // we're CamelCasing the button name (YouTube). This is just because other
      // CKEditor buttons are done this way (JustifyLeft, NumberedList etc.)
      editor.ui.addButton('uStudio', {
        label: 'uStudio',
        command: 'ustudioDialogCmd',
        icon: pluginDirectory + 'images/icon.png',
        toolbar: 'tools'
      });
    }
  });

  /*
   Our dialog definition. Here, we define which fields we want, we add buttons
   to the dialog, and supply a "submit" handler to process the user input
   and output our youtube iframe to the editor text area.
   */
  var ytDialogDefinition = function (editor) {
    var dialog = {
      title: 'uStudio',
      minWidth: 640,
      minHeight: 480,
      contents: [],
      // Add the standard OK and Cancel Buttons
      buttons: [CKEDITOR.dialog.okButton, CKEDITOR.dialog.cancelButton],
    };

    var elements = [];

    // Element: Keywords searching
    elements.push({
      id: 'filter-keyword',
      type: 'text',
      label: Drupal.t('Search keyword'),
      commit: commitValue,
      onLoad: function () {
        inputs['filter-keyword'] = this;
      }
    });

    // Element: Search by collection
    elements.push({
      type: 'hbox',
      children: [
        {
          id: 'filter-collection',
          type: 'select',
          label: Drupal.t('Collections'),
          items: [['']],
          onLoad: function () {
            var select = this;
            inputs['filter-collection'] = select;
            getCollections(function (err, data) {
              if (err) {
                alert(err);
                return;
              }

              $.each(data.collections, function () {
                select.add(this.name, this.uid);
              });
            });
          },
          commit: commitValue
        },
        {
          id: 'filter-button',
          type: 'button',
          label: Drupal.t('Filter'),
          title: Drupal.t('Filter'),
          onClick: function () {
            // console.log('clicked');
            // console.log(editor);
            var txtKeyword = inputs['filter-keyword'];
            var txtCollection = inputs['filter-collection'];
            var htmlVideos = inputs['videos'];
            htmlVideos.getElement().fire('redraw', {keyword: txtKeyword.getValue(), collection: txtCollection.getValue()});
          }
        }
      ]
    });

    elements.push({type: 'hbox', children: [{
          id: 'videos',
          type: 'html',
          html: 'Loading…',
          commit: commitValue,
          onLoad: function () {
            var self = this;
            inputs['videos'] = self;
            var elem = self.getElement();
            elem.on('redraw', function (event) {
              if (event.data && event.data.keyword) {
                getVideos.apply(self, [event.data, renderVideos]);
              } else {
                getVideos.apply(self, [renderVideos]);
              }
            });

            elem.fire('redraw');
          }
        }
      ]});

    // Add elements to the dialog
    dialog.contents.push({
      // To make things simple, we're just going to have one tab
      id: 'videos',
      label: Drupal.t('Videos'),
      title: Drupal.t('Settings'),
      expand: true,
      padding: 0,
      elements: elements
    });

    // A "submit" handler for when the OK button is clicked.
    dialog.onOk = function () {
      // A container for our field data
      var data = {};

      // Commit the field data to our data object
      // This function calls the commit function of each field element
      // Each field has a commit function (that we define below) that will
      // dump it's value into the data object
      this.commitContent(data);
      var info = data.info;

      getVideoDetail(info.videos, function (err, videoInfo) {
        var src = videoInfo.preview_embed_url.replace(/\?config=.+/, '');

        var iframe = new CKEDITOR.dom.element('iframe');
        // Add the attributes to the iframe.
        iframe.setAttributes({
          'width': 500,
          'height': 500,
          'type': 'text/html',
          'src': src,
          'frameborder': 0
        });

        // Finally insert the element into the editor.
        editor.insertElement(iframe);
      });
    };

    return dialog;
  };

  // Little helper function to commit field data to an object that is passed in:
  var commitValue = function (data) {
    var id = this.id;
    if (!data.info) {
      data.info = {};
    }
    data.info[id] = this.getValue();
  };

})(jQuery);
